==> haskell-scotty-0.21-31-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-scotty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 scotty
version:              0.21
visibility:           public
id:                   scotty-0.21-3zto5xDe9pQEpfwg6VCk18
key:                  scotty-0.21-3zto5xDe9pQEpfwg6VCk18
license:              BSD-3-Clause
copyright:            (c) 2012-Present, Andrew Farmer and the Scotty contributors
maintainer:           The Scotty maintainers
author:               Andrew Farmer <xichekolas@gmail.com>
stability:            experimental
homepage:             https://github.com/scotty-web/scotty
synopsis:
    Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp

description:
    A Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp.

    @
    &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

    import Web.Scotty

    main = scotty 3000 $
    &#32;&#32;get &#34;/:word&#34; $ do
    &#32;&#32;&#32;&#32;beam <- pathParam &#34;word&#34;
    &#32;&#32;&#32;&#32;html $ mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
    @


    Scotty is the cheap and cheerful way to write RESTful, declarative web applications.

    * A page is as simple as defining the verb, url pattern, and Text content.

    * It is template-language agnostic. Anything that returns a Text value will do.

    * Conforms to WAI Application interface.

    * Uses very fast Warp webserver by default.

    As for the name: Sinatra + Warp = Scotty.

    [WAI] <http://hackage.haskell.org/package/wai>

    [Warp] <http://hackage.haskell.org/package/warp>

category:             Web
abi:                  0831140e60a5ee4c3cdc72668a250abc
exposed:              True
exposed-modules:
    Web.Scotty Web.Scotty.Cookie Web.Scotty.Internal.Types
    Web.Scotty.Trans Web.Scotty.Trans.Strict

hidden-modules:
    Web.Scotty.Action Web.Scotty.Body Web.Scotty.Route
    Web.Scotty.Trans.Lazy Web.Scotty.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/scotty-0.21
library-dirs:         /usr/lib/ghc-9.2.8/site-local/scotty-0.21
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-scotty
hs-libraries:         HSscotty-0.21-3zto5xDe9pQEpfwg6VCk18
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp exceptions-0.10.4
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    monad-control-1.0.3.1-3jkrHBLrPTk3GVH33R4YSx mtl-2.2.2
    network-3.1.4.0-IeiVJWXSaeWHp5XfJw1SH3
    regex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy stm-2.5.0.2
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-K4FFVfATjJJFq6PHdtpZIK
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unliftio-0.2.25.0-56sfjNmy7BWDzWuwznFqC8
    wai-3.2.4-JJVI15W7E9rGAtOPSLOeBU
    wai-extra-3.1.14-KCWuHky1wkt7UnW34KzUw6
    warp-3.3.30-DAHUlH7qmMW8GtlCwsSvsK

haddock-interfaces:   /usr/share/doc/haskell-scotty/html/scotty.haddock
haddock-html:         /usr/share/doc/haskell-scotty/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-scotty-0.22-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-scotty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 scotty
version:              0.22
visibility:           public
id:                   scotty-0.22-GQVGcrw5e7l7Y6ghuh6Ds8
key:                  scotty-0.22-GQVGcrw5e7l7Y6ghuh6Ds8
license:              BSD-3-Clause
copyright:            (c) 2012-Present, Andrew Farmer and the Scotty contributors
maintainer:           The Scotty maintainers
author:               Andrew Farmer <xichekolas@gmail.com>
stability:            experimental
homepage:             https://github.com/scotty-web/scotty
synopsis:
    Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp

description:
    A Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp.

    @
    &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

    import Web.Scotty

    main = scotty 3000 $
    &#32;&#32;get &#34;/:word&#34; $ do
    &#32;&#32;&#32;&#32;beam <- pathParam &#34;word&#34;
    &#32;&#32;&#32;&#32;html $ mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
    @


    Scotty is the cheap and cheerful way to write RESTful, declarative web applications.

    * A page is as simple as defining the verb, url pattern, and Text content.

    * It is template-language agnostic. Anything that returns a Text value will do.

    * Conforms to WAI Application interface.

    * Uses very fast Warp webserver by default.

    As for the name: Sinatra + Warp = Scotty.

    [WAI] <http://hackage.haskell.org/package/wai>

    [Warp] <http://hackage.haskell.org/package/warp>

category:             Web
abi:                  4a5c351713680e336b4147c12dab7a7b
exposed:              True
exposed-modules:
    Web.Scotty Web.Scotty.Cookie Web.Scotty.Internal.Types
    Web.Scotty.Trans Web.Scotty.Trans.Strict

hidden-modules:
    Web.Scotty.Action Web.Scotty.Body Web.Scotty.Route
    Web.Scotty.Trans.Lazy Web.Scotty.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/scotty-0.22
library-dirs:         /usr/lib/ghc-9.2.8/site-local/scotty-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-scotty
hs-libraries:         HSscotty-0.22-GQVGcrw5e7l7Y6ghuh6Ds8
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp exceptions-0.10.4
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK mtl-2.2.2
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    regex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD stm-2.5.0.2 text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN
    unliftio-0.2.25.0-LM0KsdTS0NHVSVsirPxfP
    wai-3.2.4-JIqkXCnMPAzFKNQzPpgW2q
    wai-extra-3.1.15-7yDJJ6J51ruIg3TJFgMx33
    warp-3.3.30-A59ReqdFC07LgOaV7Ls0Bk

haddock-interfaces:   /usr/share/doc/haskell-scotty/html/scotty.haddock
haddock-html:         /usr/share/doc/haskell-scotty/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
